@@ -47,11 +47,7 @@ class ClassifiedsCategory(BaseBTreeFolder, BrowserDefaultMixin):
     _at_rename_after_creation = True
 
     schema = ClassifiedsCategory_schema
-
-    def getParentNodePath(self):
-        """Gets the path of the Organisatie (parent)"""
-        return self.getParentNode().getPath();
-        
+      
     def getPath(self):
         """Gets the path of the object"""
         path = '/'.join(self.getPhysicalPath());
